import {Component, Input, OnInit} from '@angular/core';
import {SimpleState} from "../../../../game-model/gamesystems/SimpleState";
import {MatTableDataSource} from "@angular/material/table";
import {animate, state, style, transition, trigger} from "@angular/animations";

@Component({
  selector: 'app-simple-state-editor',
  templateUrl: './simple-state-editor.component.html',
  styleUrl: './simple-state-editor.component.scss',
  animations: [
    trigger('detailExpand', [
      state('collapsed,void', style({height: '0px', minHeight: '0'})),
      state('expanded', style({height: '*'})),
      transition('expanded <=> collapsed', animate('225ms cubic-bezier(0.4, 0.0, 0.2, 1)')),
    ]),
  ],
})
export class SimpleStateEditorComponent implements OnInit{

  @Input() states: SimpleState[] = [];
  dataSource = new MatTableDataSource();
  displayedColumns = ["name", "initial", "edit", "delete"];
  columnsToDisplayWithExpand = [...this.displayedColumns, 'expand'];
  expandedElement: SimpleState | null = null;
  editedElement: SimpleState | null = null;

  ngOnInit() {
    this.dataSource.data = this.states;
  }

  editState(state: SimpleState) {
    if(this.editedElement === state) {
      this.editedElement = null;
    } else {
      this.editedElement = state;
    }
  }
}
